@@ -25,7 +25,7 @@ import tomllib
 from configparser import ConfigParser
 from datetime import datetime
 from os import access, chmod, environ, listdir, makedirs, walk, X_OK
-from os.path import abspath, exists, isdir, join
+from os.path import abspath, exists, isdir, join, dirname
 from shutil import copy
 
 from pypi2deb import VERSION, OVERRIDES_PATH, PROFILES_PATH, TEMPLATES_PATH
@@ -155,6 +155,9 @@ async def debianize(dpath, ctx, profile=None):
         itp_mail(dpath, ctx, env)
     copyright(dpath, ctx, env)
     watch(dpath, ctx, env)
+    # Currently only Github is supported for DEP-12
+    if 'github' in ctx:
+        upstream__metadata(dpath, ctx, env)
     clean(dpath, ctx, env)
 
     # invoke post hooks
@@ -240,7 +243,7 @@ def docs(dpath, ctx, env):
 
 
 def _render_template(func):
-    name = func.__name__
+    name = func.__name__.replace('__', '/')
 
     def _template(dpath, ctx, env, *args, **kwargs):
         fpath = join(dpath, 'debian', name)
@@ -249,6 +252,10 @@ def _render_template(func):
             return
         ctx = func(dpath, ctx, env, *args, **kwargs)
         tpl = env.get_template('debian/{}.tpl'.format(name))
+
+        if not isdir(dirname(fpath)):
+            makedirs(dirname(fpath))
+
         with open(fpath, 'w', encoding='utf-8') as fp:
             fp.write(tpl.render(ctx))
     return _template
@@ -318,6 +325,11 @@ def control(dpath, ctx, env):
     if pyproject_file.exists():
         pyproject_toml = tomllib.loads(pyproject_file.read_text())
         if 'build-system' in pyproject_toml:
+            # https://pip.pypa.io/en/stable/reference/build-system/pyproject-toml/#fallback-behaviour
+            if 'build-backend' not in pyproject_toml['build-system']:
+                log.info("Unable to detect a build backend in pyproject.toml, falling back to setuptools")
+                pyproject_toml['build-system']['build-backend'] = \
+                    "setuptools.build_meta:__legacy__"
             ctx['pybuild_depends'] = 'pybuild-plugin-pyproject'
             # static list of build backends and what package to install to use them
             backends = {
@@ -459,6 +471,11 @@ def copyright(dpath, ctx, env):
 def watch(dpath, ctx, env):
     return ctx
 
+@_render_template
+def upstream__metadata(dpath, ctx, env):
+    """Render debian/upstream/metadata according to DEP-12."""
+    return ctx
+
 
 def itp_mail(dpath, ctx, env):
     fpath = join(ctx['root'], '{src_name}_{version}-{debian_revision}.mail'.format(**ctx))
